@@ -10,7 +10,7 @@
 #' @usage
 #' 
 #' \method{plot}{trivPenalNL}(x, event = "Both", type.plot = "Hazard", conf.bands
-#' = FALSE, pos.legend="topright", cex.legend = 0.7, ylim, main, color = 2,
+#' = FALSE, pos.legend="topright", cex.legend = 0.7, ylim, main, color = 2, median=TRUE,
 #' Xlab = "Time", Ylab = "Hazard function", ...)
 #' @param x A joint model, an object of class \code{trivPenalNL}.
 #' @param event a character string specifying the type of curve. Possible value
@@ -29,6 +29,7 @@
 #' @param ylim y-axis limits
 #' @param main plot title
 #' @param color curve color (integer)
+#' @param median Logical value. Determines whether survival median will be plotted. Default is TRUE.
 #' @param Xlab Label of x-axis. Default is '"Time"'
 #' @param Ylab Label of y-axis. Default is '"Hazard function"'
 #' @param ... other unused arguments
@@ -39,7 +40,7 @@
 ##' @export
 #' @examples
 #' 
-#' \dontrun{
+#' \donttest{
 #' ###--- Trivariate joint model for longitudinal data, ---###
 #' ###--- recurrent events and a terminal event ---###
 #' 
@@ -61,26 +62,26 @@
 #' plot(model.weib.RE.gap, type = "survival")
 #' }
 "plot.trivPenalNL" <-
-  function (x, event="Both", type.plot="Hazard", conf.bands=FALSE, pos.legend="topright", cex.legend=0.7, ylim, main, color=2,  Xlab = "Time", Ylab = "Hazard function", ...)
+  function (x, event="Both", type.plot="Hazard", conf.bands=FALSE, pos.legend="topright", cex.legend=0.7, ylim, main, color=2, median=TRUE, Xlab = "Time", Ylab = "Hazard function", ...)
   {
-
+    
     event.type <- charmatch(event, c("Both", "Recurrent", "Terminal"), nomatch = 0)
     if (event.type == 0) {
       stop("event must be 'Both', 'Recurrent' or 'Terminal'")
     }
-
-
+    
+    
     plot.type <- charmatch(type.plot, c("Hazard", "Survival"), nomatch = 0)
     if (plot.type == 0) {
       stop("estimator must be 'Hazard' or 'Survival'")
     }
-
-
+    
+    
     if(missing(main))
       main<-""
-
+    
     if (event.type==1){ # both
-
+      
       if(plot.type==1){
         if (missing(ylim)){
           yymax<-max(c(x$lamR[-1], x$lamD[-1]),na.rm=TRUE)
@@ -89,16 +90,16 @@
           yymax<-ylim[2]
           yymin<-ylim[1]
         }
-
+        
         if (conf.bands){
           matplot(x$xR[,1], x$lamR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
-           matlines(x$xD, x$lamD, col=color+x$n.strat, type="l", lty=c(1,2,2), ...)
+          matlines(x$xD, x$lamD, col=color+x$n.strat, type="l", lty=c(1,2,2), ...)
         }else{
           plot(x$xR[,1], x$lamR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
           lines(x$xD, x$lamD[,1], col=color+x$n.strat, type="l", lty=1, ...)
         }
       }else{
-		if (missing(Ylab)) Ylab <- "Baseline survival function"
+        if (missing(Ylab)) Ylab <- "Baseline survival function"
         if (missing(ylim)){
           yymax<-1
           yymin<-0
@@ -110,27 +111,31 @@
           if (conf.bands){
             matplot(x$xR[,1], x$survR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
             matlines(x$xD, x$survD, col=color+x$n.strat, type="l", lty=c(1,2,2), ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xR[,1], x$survR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
             lines(x$xD, x$survD[,1], col=color+x$n.strat, type="l", lty=1, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }
         }else{
           if (conf.bands){
             matplot(x$xSuR[,1], x$survR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
             matlines(x$xSuD, x$survD, col=color+x$n.strat, type="l", lty=c(1,2,2), ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xSuR[,1], x$survR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
             lines(x$xSuD, x$survD[,1], col=color+x$n.strat, type="l", lty=1, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }
         }
       }
       if (x$n.strat > 1) legend(pos.legend, c(paste("recurrent event strata =",1:x$n.strat),"terminal event"), lty=1, col=color+(0:x$n.strat), xjust=1, cex=cex.legend, ...)
       else legend(pos.legend, c("recurrent event","terminal event"), lty=1, col=c(color,color+x$n.strat), xjust=1, cex=cex.legend, ...)
     }
-
-
+    
+    
     if (event.type==2){ # recurrent
-
+      
       if(plot.type==1){
         if (missing(ylim)){
           yymax<-max(x$lamR[-1],na.rm=TRUE)
@@ -139,14 +144,14 @@
           yymax<-ylim[2]
           yymin<-ylim[1]
         }
-
+        
         if (conf.bands){
           matplot(x$xR[,1], x$lamR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
-       }else{
+        }else{
           plot(x$xR[,1], x$lamR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
         }
       }else{
-		if (missing(Ylab)) Ylab <- "Baseline survival function"
+        if (missing(Ylab)) Ylab <- "Baseline survival function"
         if (missing(ylim)){
           yymax<-1
           yymin<-0
@@ -157,24 +162,28 @@
         if (x$typeof == 0){
           if (conf.bands){
             matplot(x$xR[,1], x$survR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xR[,1], x$survR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
-         }
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
+          }
         }else{
           if (conf.bands){
             matplot(x$xSuR[,1], x$survR[,,1], col=color, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xSuR[,1], x$survR[,1,1], col=color, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }
         }
       }
       if (x$n.strat > 1) legend(pos.legend, paste("recurrent event strata =",1:x$n.strat), lty=1, col=color+(1:x$n.strat-1), xjust=1, cex=cex.legend, ...)
       else legend(pos.legend, c("recurrent event"), lty=1, col=color, xjust=1, cex=cex.legend, ...)
     }
-
-
+    
+    
     if (event.type==3){ # terminal
-
+      
       if(plot.type==1){
         if (missing(ylim)){
           yymax<-max(x$lamD[-1],na.rm=TRUE)
@@ -183,14 +192,14 @@
           yymax<-ylim[2]
           yymin<-ylim[1]
         }
-
+        
         if (conf.bands){
           matplot(x$xD, x$lamD, col=color+x$n.strat, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
         }else{
           plot(x$xD, x$lamD[,1], col=color+x$n.strat, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
         }
       }else{
-		if (missing(Ylab)) Ylab <- "Baseline survival function"
+        if (missing(Ylab)) Ylab <- "Baseline survival function"
         if (missing(ylim)){
           yymax<-1
           yymin<-0
@@ -201,19 +210,23 @@
         if (x$typeof == 0){
           if (conf.bands){
             matplot(x$xD, x$survD, col=color+x$n.strat, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xD, x$survD[,1], col=color+x$n.strat, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }
         }else{
           if (conf.bands){
             matplot(x$xSuD, x$survD, col=color+x$n.strat, type="l", lty=c(1,2,2), xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }else{
             plot(x$xSuD, x$survD[,1], col=color+x$n.strat, type="l", lty=1, xlab=Xlab,ylab=Ylab, ylim=c(yymin,yymax), main=main, ...)
+            if (median){abline(a=0.5,b=0,cex=.5,col=1,lty=3)}
           }
         }
       }
       legend(pos.legend, c("terminal event"), lty=1, col=color+x$n.strat, xjust=1, cex=cex.legend, ...)
     }
-
+    
     return(invisible())
   }
