@@ -91,24 +91,36 @@
         tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
         if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq, x$dof_chisq, ifelse(x$p.global_chisq == 0, "< 1e-16", x$p.global_chisq))
         if(x$global_chisq.test_d==1) tmpwalddc <- cbind(x$global_chisq_d, x$dof_chisq_d, ifelse(x$p.global_chisq_d == 0, "< 1e-16", x$p.global_chisq_d))
+       if(x$TwoPart==1)if(x$global_chisq.test_B==1) tmpwaldB <- cbind(x$global_chisq_B,x$dof_chisq_B,x$p.global_chisq_B)#add TwoPart             
       }else{
         tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - pchisq((coef/seH)^2, 1), digits - 1))
         if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq, x$dof_chisq, ifelse(x$p.global_chisq == 0, "< 1e-16", x$p.global_chisq))
         if(x$global_chisq.test_d==1) tmpwalddc <- cbind(x$global_chisq_d, x$dof_chisq_d, ifelse(x$p.global_chisq_d == 0, "< 1e-16", x$p.global_chisq_d))
+        if(x$TwoPart==1)if(x$global_chisq.test_B==1) tmpwaldB <- cbind(x$global_chisq_B,x$dof_chisq_B,x$p.global_chisq_B)#add TwoPart                   
       }
       
       cat("\n")
-      
-      cat("  Joint Model for Longitudinal Data and a Terminal Event","\n")
-      
-      if (x$typeof == 0){
-        cat("  Parameter estimates using a Penalized Likelihood on the hazard function","\n")
-      }else{
-        cat("  Parameter estimates using a Parametrical approach for the hazard function","\n")
-      }
-      
+
+      if(x$TwoPart==0){
+          cat("  Joint Model for Longitudinal Data and a Terminal Event","\n")
+
+        if (x$typeof == 0){
+          cat("  Parameter estimates using a Penalized Likelihood on the hazard function","\n")
+        }else{
+          cat("  Parameter estimates using a Parametrical approach for the hazard function","\n")
+        }
+        
       if(x$leftCensoring==TRUE)cat("  and assuming left-censored longitudinal outcome \n")
-      
+      }else if(x$TwoPart==1){
+      if(x$TwoPart==1)cat("Joint Model for Semi-continuous Data and a Terminal Event\n")
+        if (x$typeof == 0){
+          cat("  Parameter estimates using a Penalized Likelihood on the hazard function","\n")
+        }else{
+          cat("  Parameter estimates using a Parametrical approach for the hazard function","\n")
+        }
+        cat("Conditional Two-Part model with correlated random-effects for Semi-continuous outcome\n")
+      }
+
       if(x$link=='Random-effects') cat("  Association function: random effects","\n")
       if(x$link=='current-level') cat("  Association function: current level of the longitudinal outcome","\n")
       
@@ -144,6 +156,12 @@
           dimnames(tmpwalddc) <- list(x$names.factordc,c("chisq", "df", "global p"))
           
         }
+        if(x$TwoPart==1){ #add TwoPart
+            if(x$global_chisq.test_B==1){
+              dimnames(tmpwaldB) <- list(x$names.factorB,c("chisq", "df", "global p"))
+
+            }
+        }      
         dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
                                              "SE coef (H)", "SE coef (HIH)", "z", "p"))
       }else{
@@ -154,21 +172,57 @@
         if(x$global_chisq.test_d==1){
           dimnames(tmpwalddc) <- list(x$names.factordc,c("chisq", "df", "global p"))
           
+
+        }
+        if(x$TwoPart==1){ #add TwoPart
+            if(x$global_chisq.test_B==1){
+          dimnames(tmpwaldB) <- list(x$names.factorB,c("chisq", "df", "global p"))
+
+            }  
         }
         dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)",
                                              "SE coef (H)", "z", "p"))
       }
-      
-      if (x$noVarY == 0){
-        cat("Longitudinal outcome:\n")
-        cat("---------------- \n")
-        prmatrix(tmp[-c(1:(x$nvarEnd)),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
-        if(x$global_chisq.test==1){
-          cat("\n")
-          prmatrix(tmpwald)
+    if(x$TwoPart==1){
+        if (x$noVarB == 0){
+          cat("Binary outcome:\n")
+          cat("---------------- \n")
+          prmatrix(tmp[-c(1:(x$nvarY+x$nvarEnd)),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
+          if(x$global_chisq.test_B==1){
+            cat("\n")
+            prmatrix(tmpwaldB)
+          }
         }
-      }
+      cat("\n")
+        if (x$noVarY == 0){
+          cat("Semi-continuous outcome:\n")
+          cat("---------------- \n")
+          if(!x$GLMlog){
+            prmatrix(tmp[c((x$nvarEnd+1):(x$nvarY+x$nvarEnd)),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
+          }else if(x$GLMlog){
+            prmatrix(tmp[c((x$nvarEnd+1):(x$nvarY+x$nvarEnd)),,drop=FALSE],quote=FALSE,right=TRUE)
+          }
+          if(x$global_chisq.test==1){
+            cat("\n")
+            prmatrix(tmpwald)
+          }
+        }
+    }else if(x$TwoPart==0){
       
+        if (x$noVarY == 0){
+          cat("Longitudinal outcome:\n")
+          cat("---------------- \n")
+          if(!x$GLMlog){
+          prmatrix(tmp[-c(1:(x$nvarEnd)),-2 ,drop=FALSE],quote=FALSE,right=TRUE)
+          }else if(x$GLMlog){
+            prmatrix(tmp[-c(1:(x$nvarEnd)),,drop=FALSE],quote=FALSE,right=TRUE)
+          }
+          if(x$global_chisq.test==1){
+            cat("\n")
+            prmatrix(tmpwald)
+          }
+        }
+    }   
       cat("\n")
       #for further developments
       #      if (x$nvarnotdep[1] == 0){
@@ -183,6 +237,7 @@
         if(x$global_chisq.test_d==1){
           cat("\n")
           prmatrix(tmpwalddc)
+           
         }
       }
       #  }
@@ -243,7 +298,8 @@
       #  tab.Asso[which,4]<-"<1e-16"
       # tab.Asso <- round(tab.Asso,digits)
       # tab.Asso[which(tab.Asso[,4]==0),4]<-noquote("<1e-16")
-      dimnames(tab.Asso) <- list(x$names.re,c("coef",  "SE", "z", "p"))
+     if(x$TwoPart==0) dimnames(tab.Asso) <- list(x$names.re,c("coef",  "SE", "z", "p"))
+      if(x$TwoPart==1) dimnames(tab.Asso) <- list(x$names.re,c("coef",  "SE", "z", "p"))
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
     }else{
       tab.Asso <- cbind(x$eta, x$se.eta, x$eta/x$se.eta, signif(1 - pchisq((x$eta/x$se.eta)^2, 1), digits - 1))
@@ -271,7 +327,11 @@
       # tab.Asso[which,4]<-"<1e-16"
       # tab.Asso <- round(tab.Asso,digits)
       # tab.Asso[which(tab.Asso[,4]==0),4]<-noquote("<1e-16")
-      dimnames(tab.Asso) <- list("Current level",c("coef",  "SE", "z", "p"))
+if(x$link=='Current-level'){
+     dimnames(tab.Asso) <- list("Current level",c("coef",  "SE", "z", "p"))
+     }else if (x$link=="Two-part"){
+     dimnames(tab.Asso) <- list(c("Binary part", "Continuous part"),c("coef",  "SE", "z", "p"))
+     }
       prmatrix(tab.Asso,quote=FALSE,right=TRUE)
     }
     
@@ -315,7 +375,9 @@
     cat("\n")
     cat("      n=", x$groups)
     cat("\n")
-    cat("      n repeated measurements=", x$n.measurements)
+    if(x$TwoPart==0) cat("      n repeated measurements=", x$n.measurements)
+    if(x$TwoPart==1) cat("\n      n repeated measurements (Semi-continuous)=", x$n.measurements)
+    if(x$TwoPart==1) cat("\n      n repeated measurements (Binary)=", x$n.measurementsB)                   
     if(x$leftCensoring)cat("\n      Percentage of left-censored measurements=",round(x$prop.censored,4)*100,"%\n      Censoring threshold s=",x$leftCensoring.threshold)
     if (length(x$na.action)){
       cat("  (", length(x$na.action), " observation deleted due to missing) \n")
