@@ -123,11 +123,18 @@
 !  1: critere d'arret satisfait (prm=ca, vraisblce=cb, derivee=dd)
 !  2: nb max d'iterations atteints
 !  4: Erreur
+    use residusM,only:indg
+    ! use parameters
+    ! use comon,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
+    ! nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
+    ! PEN_deri,Hspl_hess,indic_ALPHA,typeof,indic_eta
+    use parameters,only:epsa,epsb,epsd,maxiter
+    use comon,only:nva,model,indic_ALPHA,typeof
     !use residusM,only:indg
-    use parameters
-    use comon,only: nva, & !t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc
-    model, & !nt1dc,nsujet,nva1,nva2,ndate,ndatedc,nst
-    indic_ALPHA,typeof !PEN_deri,Hspl_hess,indic_eta
+    !use parameters
+    !use comon,only: nva, & !t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc
+    !model, & !nt1dc,nsujet,nva1,nva2,ndate,ndatedc,nst
+    !indic_ALPHA,typeof !PEN_deri,Hspl_hess,indic_eta
 
 !add additive
     !use additiv,only:correl
@@ -143,12 +150,12 @@
     ! double precision,dimension(size(vvv)),intent(out)::vvv
     
     !double precision,dimension(:,:),intent(inout)::wij_chap
-    double precision,dimension(:,:),intent(inout)::I_hess
-    double precision,dimension(:,:),intent(inout)::H_hess
-    double precision,dimension(:,:),intent(inout)::hess
-    double precision,dimension(:),intent(inout)::vvv
-
     integer,intent(in) :: m,effet
+    double precision,dimension(m,m),intent(inout)::I_hess
+    double precision,dimension(m,m),intent(inout)::H_hess
+    double precision,dimension(m,m),intent(inout)::hess
+    double precision,dimension(m*(m+1)/2),intent(inout)::vvv
+
     integer,intent(inout)::ni,ier,istop
     double precision,dimension(m*(m+3)/2),intent(out)::v
     double precision,intent(out)::rl
